@@ -1,6 +1,6 @@
-# -*- coding=utf-8 -*-
+# -*- coding: utf-8  -*-
 
-LICENSE = '''
+GPL = '''
                     GNU GENERAL PUBLIC LICENSE
                        Version 3, 29 June 2007
 
@@ -620,258 +620,205 @@ reviewing courts shall apply local law that most closely approximates
 an absolute waiver of all civil liability in connection with the
 Program, unless a warranty or assumption of liability accompanies a
 copy of the Program in return for a fee.
+'''
 
-                     END OF TERMS AND CONDITIONS
+LICENSE = '''
+Python-Extension 1.5.4
+Copyright (C) 2021  Yile Wang
 
-            How to Apply These Terms to Your New Programs
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-  If you develop a new program, and you want it to be of the greatest
-possible use to the public, the best way to achieve this is to make it
-free software which everyone can redistribute and change under these terms.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-  To do so, attach the following notices to the program.  It is safest
-to attach them to the start of each source file to most effectively
-state the exclusion of warranty; and each file should have at least
-the "copyright" line and a pointer to where the full notice is found.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-    Python-Extension
-    Copyright (C) 2021  Yile Wang
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-Also add information on how to contact you by electronic and paper mail.
-
-  If the program does terminal interaction, make it output a short
-notice like this when it starts in an interactive mode:
-
-    Python-Extension  Copyright (C) 2021  Yile_Wang
-    This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
-    This is free software, and you are welcome to redistribute it
-    under certain conditions; type `show c' for details.
-
-The hypothetical commands `show w' and `show c' should show the appropriate
-parts of the General Public License.  Of course, your program's commands
-might be different; for a GUI interface, you would use an "about box".
-
-  You should also get your employer (if you work as a programmer) or school,
-if any, to sign a "copyright disclaimer" for the program, if necessary.
-For more information on this, and how to apply and follow the GNU GPL, see
-<https://www.gnu.org/licenses/>.
-
-  The GNU General Public License does not permit incorporating your program
-into proprietary programs.  If your program is a subroutine library, you
-may consider it more useful to permit linking proprietary applications with
-the library.  If this is what you want to do, use the GNU Lesser General
-Public License instead of this License.  But first, please read
-<https://www.gnu.org/licenses/why-not-lgpl.html>.
 '''
 
 MESSAGE = '''
 Python-Extension
-Version : 1.3.3
+Version : 1.5.4
 Author : Yile Wang
-Copyright : Yile Wang
 License : GNU General Public License
 Python Requires : At least Python 2.7
-Module Requires : Python-docx ( At least 0.8 )
 '''
 
 DESCRIPTION = '''
-Brief Introduction
+Brief Introduction of Python-Extension
 
-Python-Extension is an extension of Python,
-It is divided into pyextension and tkextension,
-tkextension is particularly powerful. 
+Python-Extension is an extension of Python.
 
 
-Pyextensionass
+What's New In Python-Extension 1.5
+  Python-Extension
+    1.Module requirements removed ( python-docx 0.8 and above )
+  Pyextension
+    Pyextension
+      1.New function pyextension.clear() to clear the cache ( consistent with function test._clear() )
+    Mathematics
+      1.Removed version requirements ( Python 3.10 and above )
+    Password
+      1.Removed old encrypt / decrypt functions
+      2.New encrypt / decrypt classes
+        Example:
+          from pyextension.password import *
+          # Encrypt
+          en = Encrypt('encrypt', undo=False)
+          en.caesar(5)
+          print(en.get())
+          >>> jshwDuy
+          en.vigenere('python')
+          print(en.get())
+          >>> yQADRHN
+
+          # Decrypt
+          de = Decrypt(en.get(), undo=False)
+          de.vigenere('python')
+          print(de.get())
+          >>> jshwDuy
+          de.caesar(5)
+          print(de.get())
+          >>> encrypt
+    Test
+      1.Now can delete the cache 'word bank.dat' using test._clear()
+    Unicode
+      1.New module Unicode
+      2.Function search(thing)
+        If thing is a string type, return the unicode number of it
+        If thing is a int type, return the corresponding character of it
+      3.Function table(items, cols, add_numbers=False)
+        Returns a UTF-8 / ASCII table with cols columns
+        If the parameter add_numbers is true,
+        the corresponding encoding sequence number will be added before the encoding character
+      4.Function listcode(items, add_numbers=False)
+        Returns a UTF-8 / ASCII list
+        If the parameter add_numbers is true,
+        the corresponding encoding sequence number will be added before the encoding character
+    Word Bank
+      1.Added new Word Bank Data
+      2.New function word_bank.uninstall(location), word_bank.get()
+    Word
+      1.Removed module Word
+  
+  Tkextension
+    Tkextension
+      1.All dialog windows are now created using the components of the tkextension.tix library
+    Blackboard
+      1.Now it belongs to the tkextension.tix library(tkextension.tix.blackboard), but it can still be imported using 'import tkextension.blackboard'
+      2.Now can choose sqrite that draw when click right-button
+    Timer
+      1.Now it belongs to the tkextension.tix library(tkextension.tix.timer), but it can still be imported using 'import tkextension.timer'
+
+
+What's Change In Python-Extension 1.5.4
+  Python-Extension
+    1.Python-Extension is available now
+      In Python-Extension 1.5.4:
+        >>> # Python 3.10.0 on OS X 10.9.5
+        >>> p = __import__("pyextension")
+        <module 'pyextension' from '/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/site-packages/pyextension/__init__.py'>
+        >>> p.clear()
+        >>>
+
+
+Pyextension
 
 Pyextension includes main modules
-(open source function, computer information function),
+(about function, open source function, computer information function, quick document processing),
 mathematical function processing module, password encryption module,
-English Thesaurus module and Microsoft Word document processing module.
+unicode module and English Thesaurus module.
 
 
 Tkextension
 
-Tkextense includes dialog window,tix widget,
+Tkextense includes dialog window, tix widget,
 quick generation of Tkinter object,
-quick document processing (open and save as),
+tix module, tix.blackboard module,
+tix.filedialog module, tix.timer module
 open source module,
-tix module, ttk module,
-small blackboard module, turtle graphics drawing module and timer module
+and turtle graphics drawing module
 '''
 
-word = {
-    'a' : [
-        'a',
-        'able',
-        'ability',
-        'achivement',
-        'again',
-        'all',
-        'alpha',
-        'alphabet'
-        'am',
-        'an',
-        'ant',
-        'any',
-        'angry',
-        'anyone',
-        'anybody',
-        'anywhere',
-        'apple',
-        'apply',
-        'application',
-        'April',
-        'are',
-        'as',
-        'aunt',
-        'August',
-        'awful',
-        ''
-        ],
-    'b' : [
-        'b',
-        'bank',
-        'base',
-        'basic',
-        'banana',
-        'basket',
-        'baseball',
-        'basketball',
-        'beach',
-        'bit',
-        'bin',
-        'boom',
-        'bring',
-        'bridge',
-        'bright',
-        ''
-        ],
-    'c' : [
-        'c',
-        'car',
-        'cake',
-        'case',
-        'cash',
-        'caugh',
-        'canvas',
-        'cabbage',
-        'celebrate',
-        'cell',
-        'cute',
-        ],
-    'd' : [
-        'd',
-        'data',
-        'date',
-        'dance',
-        'dancer',
-        'danger',
-        'dangeons',
-        'desktop',
-        'December',
-        'dist',
-        'dictionary'
-        'document',
-        'duck',
-        ],
-    'e' : [
-        'e',
-        'egg',
-        'else',
-        'entry',
-        'entrance',
-        'explore',
-        'explorer',
-        ],
-    'f' : [
-        'f',
-        'float',
-        'flow',
-        'fade',
-        'fuck',
-        'fucking',
-        'find',
-        'found',
-        'founder',
-        'fix',
-        'fat'
-        ],
-    'g' : [
-        'g'
-        ],
-    'h' : [
-        'h'
-        ],
-    'i' : [
-        'i'
-        ],
-    'j' : [
-        'j'
-        ],
-    'k' : [
-        'k'
-        ],
-    'l' : [
-        'l'
-        ],
-    'm' : [
-        'm'
-        ],
-    'n' : [
-        'n'
-        ],
-    'o' : [
-        'o'
-        ],
-    'p' : [
-        'p'
-        ],
-    'q' : [
-        'q'
-        ],
-    'r' : [
-        'r'
-        ],
-    's' : [
-        's'
-        ],
-    't' : [
-        't'
-        ],
-    'u' : [
-        'u'
-        ],
-    'v' : [
-        'v'
-        ],
-    'w' : [
-        'w'
-        ],
-    'x' : [
-        'x'
-        ],
-    'y' : [
-        'y'
-        ],
-    'z' : [
-        'z'
-        ]
-    }
+import os
 
+def clear():
+    try:
+        for root, dirs, files in os.walk('__pycache__', topdown=False):
+            for name in files:
+                os.remove(os.path.join(root, name))
+        os.rmdir('__pycache__')
+    except OSError:
+        pass
+    try:
+        for root, dirs, files in os.walk('word_bank/__pycache__', topdown=False):
+            for name in files:
+                os.remove(os.path.join(root, name))
+        os.rmdir('word_bank/__pycache__')
+    except OSError:
+        pass
+    try:
+        os.remove('word bank.dat')
+    except OSError:
+        pass
+
+import pickle
+
+try:
+    file = open('word_bank/word bank.dat', 'rb')
+    WORDBANK = pickle.load(file)
+    file.close()
+except OSError:
+    try:
+        import pyextension.word_bank.word_bank_value
+        WORDBANK = pyextension.word_bank_word_value.get()
+    except:
+        WORDBANK = {}
+
+import pickle
+
+def fopen(filetypes=[('TXT','.txt'), ('PY', '.py')], mode='r', encoding='utf-8', path=None):
+    if path == None:
+        location = askopenfilename(filetypes=filetypes)
+    else:
+        location = askopenfilename(filetypes=filetypes, initialdir=path)
+    if mode == 'r':
+        if path == None:
+            return (open(location, encoding=encoding).read(), location)
+        else:
+            return open(location, encoding=encoding).read()
+    elif mode == 'rb':
+        if path == None:
+            return (pickle.load(open(location, 'rb')), location)
+        else:
+            return pickle.load(open(location, 'rb'))
+    else:
+        raise ValueError('usemode cannot be %s' % mode)
+def fsave(things_to_save, filetypes=[('TXT', '.txt'), ('PY', '.py')], mode='w', encoding='utf-8', path=None):
+    if path == None:
+        location = asksaveasfilename(filetypes=filetypes)
+    else:
+        location = asksaveasfilename(filetypes=filetypes, initialdir=path)
+    if mode == 'w':
+        if path == None:
+            open(location, encoding=encoding).write(things_to_save)
+            return location
+        else:
+            open(location, encoding=encoding).write(things_to_save)
+    elif mode == 'wb':
+        if path == None:
+            pickle.dump(things_to_save, open(location, 'wb'))
+            return location
+        else:
+            pickle.dump(things_to_save, open(location, 'wb'))
+    else:
+        raise ValueError('usemode cannot be %s' % mode)
+# File
 import platform as p
 import sys
 
@@ -930,7 +877,7 @@ def python():
 import pickle
 
 def opensource(module='pyextension'):
-    if module == 'pyextension' or module == '__init__':
+    if module == 'pyextension':
         file = open('__init__.py')
         get = file.read()
         file.close()
@@ -940,8 +887,13 @@ def opensource(module='pyextension'):
         get = file.read()
         file.close()
         return get
-    elif module == 'math':
-        file = open('math.py')
+    elif module == 'math' or module == 'mathematics':
+        file = open('mathematics.py')
+        get = file.read()
+        file.close()
+        return get
+    elif module == 'unicode':
+        file = open('unicode.py')
         get = file.read()
         file.close()
         return get
@@ -952,20 +904,23 @@ def opensource(module='pyextension'):
         return get
     elif module == 'word bank data':
         try:
-            file = open('word_bank/word bank.dat.py', 'rb')
+            file = open('word_bank/word bank.dat', 'rb')
             get = pickle.load(file)
             file.close()
             return get
         except OSError:
-            return word
-    elif module == 'word':
-        file = open('word.py')
-        get = file.read()
-        file.close()
-        return get
+            import word_bank
+            clear()
+            return word_bank.get()
     else:
         raise AttributeError('\'opensource\' object has no attribute \'%s\'' % module)
 
+def GNU_General_Public_License():
+    return GPL
+
+def GPL() -> 'GNU General Public License':
+    return GPL
+
 def license():
     return LICENSE
 
@@ -975,17 +930,5 @@ def message():
 def description():
     return DESCRIPTION
 
-def _test():
-    computer
-    computer()
-    python
-    python()
-    opensource('pyextension')
-    opensource('math')
-    opensource('password')
-    opensource('word')
-    opensource('word bank')
-    opensource('word bank data')
-    license()
-    message()
-    description()
+def word_bank():
+    return WORDBANK
