@@ -1,15 +1,10 @@
 # -*- coding: utf-8  -*-
 
-import sys
-if sys.version_info[0] != 3 or sys.version_info[1] < 4:
-    raise SystemExit('This module needs Python 3.4 or more later')
-
 from tkinter import *
 from tkinter.colorchooser import *
 from tkextension.tix.dialog import *
-import tkextension as tix
 
-class BlackBoard(tix.Layout):
+class BlackBoard():
     def __init__(self, tkinter_attribute, width=400, height=200, bg='#ffffff'):
         self.sqrite_type = 'line' # Sqrite
         self.color = 'black' # Color
@@ -47,6 +42,8 @@ class BlackBoard(tix.Layout):
         self.canvas.bind('<ButtonRelease-1>', self.offslide)
         self.canvas.bind('<Motion>', self.draw)
         # Bind
+    def get(self):
+        return self.frame
     def key(self, event):
         if event.char == 'A' or event.char == 'a':
             self.colorchoose(event)
