@@ -1,12 +1,11 @@
-# -*- coding:utf-8  -*-
+# -*- coding: utf-8  -*-
 
 from tkinter import *
-import tkextension.tix as tix
 import platform as p
 import getpass
 import os
 
-class FileTree(tix.Layout):
+class FileTree():
     def __init__(self, tkinter_attribute, filetypes=[('All Files', '')], path=None, width=200, height=200):
         self.filetypes = filetypes
         self.location = ''
@@ -68,6 +67,8 @@ class FileTree(tix.Layout):
         self.tree.bind('<Double-Button-1>', self.into)
         # Bind
         self.update()
+    def get(self):
+        return self.frame
     def relist(self, event=None, mode='entry'):
         if mode == 'entry':
             self.location = self.entry.get()
